using System;
using System.IO;
using System.Text;
using System.Collections.Specialized;

namespace WidReader.Data
{
    public class ShiftJisReader : BinaryReader
    {
        private static Encoding sjisEnc 
            = Encoding.GetEncoding("shift-jis");
        private static char[] CR = { '\r' };
        private static char[] LF = { '\n' };

        public ShiftJisReader(Stream output) : base(output, sjisEnc) 
        {
        }

        // 摜KvȂꍇɎ܂Ńt@C|C^ړ
        public void SkipToNext()
        {
            int size = ReadInt32();
            if (size != 0) SkipBytes(size);
        }

        // t@C|C^ړ
        public void SkipBytes(long size)
        {
            this.BaseStream.Seek(size, SeekOrigin.Current);
        }

        /// <summary>
        /// t@CI[H
        /// </summary>
        /// <returns></returns>
        public bool IsEOF()
        {
            return this.PeekChar() < 0;
        }

        //J[h[X4byte + NULLI[ɓK
        public override string ReadString()
        {
            int len = ReadInt32();
            byte[] bs = ReadBytes(len - 1);
            if (bs.Length < len - 1)
                throw new EndOfStreamException();
            ReadByte();
            return sjisEnc.GetString(bs);
        }

        //s؂肾stringňf[^p
        public string ReadStringCRLF()
        {
            int len = ReadInt32();
            byte[] bs = ReadBytes(len);
            if (bs.Length < len)
                throw new EndOfStreamException();
            return sjisEnc.GetString(bs);
        }

        //sR[h؂蕶p
        public StringCollection ReadStringCollection()
        {
            int len = ReadInt32();
            if (len == 0)
            {
                return new StringCollection();
            }
            byte[] bs = ReadBytes(len);
            if (bs.Length < len)
                throw new EndOfStreamException();
            string s = sjisEnc.GetString(bs);
            string[] sa = s.Split(LF);
            StringCollection sc = new StringCollection();
            int i, leng = sa.Length - 1;
            for (i = 0; i < leng; i++)
                sc.Add(sa[i].TrimEnd(CR));
            return sc;
        }


    }
}
